<?php
// $Id: kwresearch.admin.inc,v 1.1.2.1 2010/06/03 22:20:20 tomdude48 Exp $

/**
 * @file
 * Admin include file.
 */

/**
 * Displays the form for the standard settings tab.
 *
 * @return
 *   array A structured array for use with Forms API.
 */
function kwresearch_admin_settings() {
 
  $apikey = variable_get('kwresearch_apikey','');
  $form['kwresearch_apikey'] = array(
    '#type' => 'textfield',
    '#title' => t('WordTracker API Key'), 
    '#default_value' => $apikey,
    '#description' => t('You need an API key to enable keyword statistics and related phrase lookups. If you have a Wordtracker API key enter it above. To get a full API key, contact !wordtracker_link. You can also use a free !levelten_link to enable demo level access to Wordtracker statitics.',
      array(
        '!wordtracker_link' => l(t('Wordtracker'), 'http://www.wordtracker.com/api', array('attributes' => array('target', 'wordtracker'))),
        '!levelten_link' => l(t('LevelTen SEO API key'), 'http://www.leveltendesign.com/user/0/l10seoapi', array('attributes' => array('target', 'levelten'))),
      )
    ),
  );
  
  if(!module_exists('scribeseo')) {
    $msg = t('You can also use the Scribe SEO API as a source for keyword statitics; !link.',
      array(
        '!link' => l(t('download and install Scribe SEO'), 'http://drupal.org/project/scribeseo', array('attributes' => array('target' => 'drupal'))),
      )
    );
  }
  elseif(!variable_get('scribeseo_apikey', '')) {
    $msg .= t('You can also use the Scribe SEO API as a source for keyword statitics. The Scribe module is installed, however an the API key is missing; !link.',
      array(
        '!link' => l(t('enable the Scribe API key'), 'admin/settings/scribeseo', array('attributes' => array('target' => 'drupal'))),
      )
    );  
  }
  else {
    $msg = t('The Scribe API is enabled as a keyword data source.');
  }
  $form['scribe_apikey'] = array(
    '#type' => 'item',
    '#title' => t('Scribe API Key'), 
    '#value' => $msg,  
  );
  
  if($apikey) {
    $perms = variable_get('kwresearch_api_perms','');
    if(!$perms || ($perms['apikey'] != $apikey)) {
      $perms = kwresearch_api_query_permissions();
      $perms['apikey'] = $apikey;
      //variable_set('kwresearch_api_perms',kwresearch_api_query_permissions());
      //dsm($perms);
    }
    
    $form['kwresearch_acctstatus_hdr'] = array(
      '#type' => 'markup',
      '#value' => '<h3>' . t('Account Permissions') . '</h3>', 
    );
    $statuses = array(
      'get_all_words_popularity' => t('Get all words popularity'),
      'get_embedded_phrase_popularity' => t('Get embedded phrase popularity'),
      'get_exact_phrase_popularity' => t('Get exact phrase popularity'),
      'get_plurals' => t('Get plurals'),
      'get_lateral_keyphrases' => t('Get lateral keyphrases'),
      'get_thesaurus_keyphrases' => t('Get thesaurus keyphrases'),
    );
    foreach($statuses AS $k => $v) {
      $enabled = 'N';
      if($perms[$k]) {
        $limit = $perms[$k]['result_limit'];
        if($limit > 0) {
          $enabled = 'Y (limit '.$limit.')';
        }
      }
      $form['kwresearch_'.$k] = array(
        '#type' => 'item',
        '#title' => $v, 
        '#value' => "Enabled: ".$enabled,
      );
    }
  }
  
  $form['kwresearch_popularity_report_options'] = array(      
    '#type' => 'fieldset',      
    '#title' => t('Popularity report options'),      
    '#collapsible' => TRUE,      
    '#collapsed' => FALSE,    
  );
  $vocabs = taxonomy_get_vocabularies();
  $options = array(0 => t('None'));
  foreach($vocabs AS $vid => $v) {
    if($v->tags) {
      $options[$vid] = $v->name;
    }
  }
  $form['kwresearch_keyword_vocabulary'] = array(    
    '#type' => 'radios',    
    '#title' => t('Keyword vocabulary'),   
    '#options' => $options,
    '#default_value' => variable_get('kwresearch_keyword_vocabulary', 0),     
    '#description' => t('If you have a vocabulary for storing keywords, select it here. Only vocabularies with tags enabled are available.')     
  ); 

  $options = kwresearch_get_report_data_options(); 
  $def_values = kwresearch_get_report_data_options_defaults();
//dsm(variable_get('kwresearch_popularity_report_columns', $def_values));
  $form['kwresearch_popularity_report_options']['kwresearch_popularity_report_data_options'] = array(    
    '#type' => 'checkboxes',    
    '#title' => t('Report data'),   
    '#options' => $options,
    '#default_value' => variable_get('kwresearch_popularity_report_data_options', $def_values),     
    //'#description' => t('')     
  ); 
  
  $options = kwresearch_get_report_links_options(); 
  $def_values = kwresearch_get_report_links_options_defaults();
  $form['kwresearch_popularity_report_options']['kwresearch_popularity_report_links_options'] = array(    
    '#type' => 'checkboxes',    
    '#title' => t('Report links'),   
    '#options' => $options,
    '#default_value' => variable_get('kwresearch_popularity_report_links_options', $def_values),     
    //'#description' => t('')     
  ); 

  return system_settings_form($form);
}

